<?php

/**
 * Modbash Clean Elgg Theme
 *
 * Copyright (c) 2015 ModBash
 *
 * @author     Shane Barron <admin@modbash.com>
 * @copyright  2015 SocialApparatus
 * @license    GNU General Public License (GPL) version 2
 * @version    1
 * @link       http://modbash.com
 */
require_once __DIR__ . '/vendor/autoload.php';
elgg_register_event_handler('init', 'system', 'unl_theme_init');


function unl_theme_init() {

    elgg_unextend_view('page/elements/header', 'search/header');
    elgg_extend_view('page/elements/sidebar', 'search/header', 0);
    
    elgg_require_js("elgg/Plugin");
    elgg_require_js("elgg/spinner");

    if (elgg_get_context() != "admin") {
        elgg_require_js("unl_theme/js");
    }

    elgg_register_event_handler('pagesetup', 'system', 'unl_theme_pagesetup', 1000);

    elgg_register_plugin_hook_handler('head', 'page', 'unl_theme_setup_head');

    $bower = elgg_get_site_url() . "mod/unl_theme/vendors/bower_components/";

    elgg_register_css("open", "https://fonts.googleapis.com/css?family=Open+Sans:400,700,700italic,400italic");
    elgg_register_css("passion", "https://fonts.googleapis.com/css?family=Passion+One");
    elgg_register_css("unl_theme", elgg_get_site_url() . "mod/unl_theme/css/unl_theme.css", 10000);
    elgg_register_css("font-awesome", "{$bower}fontawesome/css/font-awesome.min.css");
    // elgg_register_css("fuelux", "{$bower}fuelux/dist/css/fuelux.min.css");
    elgg_register_css("agency", elgg_get_site_url() . "mod/unl_theme/css/planetred.css", 20000);
    elgg_register_css("home", elgg_get_site_url() . "mod/unl_theme/css/home.css", 30000);
    elgg_register_js('respond', 'mod/unl_theme/vendors/bower_components/respond/src/respond.js');
    elgg_define_js("bootstrap", array("src" => "{$bower}bootstrap/dist/js/bootstrap.min.js"));
    elgg_register_js("bootstrap-select", "{$bower}bootstrap-select/dist/js/bootstrap-select.min.js");
    elgg_register_js("jasny", "{$bower}jasny-bootstrap/dist/js/jasny-bootstrap.min.js");
    elgg_register_js("cbpAnimatedHeader", elgg_get_site_url() . "mod/unl_theme/js/cbpAnimatedHeader.js");
    elgg_register_js("classie", elgg_get_site_url() . "mod/unl_theme/js/classie.js");
    elgg_register_js("scrollspy", "{$bower}scrollspy/jquery.scrollspy.js");
    // elgg_register_js("parallax", "{$boder}jquery-parallax/scripts/jquery.parallax-1.13.js");
    // elgg_register_js("scrollto", "{$bower}jquery-parallax/scripts/jquery.scrollTo-1.4.2-min.js");
    // elgg_define_js('fuelux', array(
        // 'src' => "{$bower}fuelux/dist/js/fuelux.js",
    // ));

    if (elgg_get_context() != "admin") {
        /**
         * Elgg has its own requireJS, and expects a different baseURL than the UNL framework. Reset back to the framework.
         * Only do this for the main interface, the admin interface requires requirejs.
         */
        $base_url = elgg_get_site_url();

        //Add paths stuff to the requirejs config
        _elgg_services()->amdConfig->removePath('languages/en');
        _elgg_services()->amdConfig->addPath('languages/en', $base_url.'js/languages');
        _elgg_services()->amdConfig->addPath('elgg/reportedcontent', $base_url.'mod/reportedcontent/views/default/elgg/reportedcontent');
        _elgg_services()->amdConfig->addPath('elgg/UserPicker', $base_url.'views/default/elgg/UserPicker');
        _elgg_services()->amdConfig->addPath('unl_theme/js', $base_url.'mod/unl_theme/views/default/js/unl_theme/js');
        _elgg_services()->amdConfig->addPath('unl_theme/jquery.imgareaselect', $base_url.'mod/unl_theme/js/jquery.imgareaselect');
        _elgg_services()->amdConfig->addPath('bootstrap', $base_url.'mod/unl_theme/vendors/bower_components/bootstrap/dist/js/bootstrap');
        _elgg_services()->amdConfig->addPath('moment', $base_url.'mod/unl_theme/vendors/bower_components/moment/moment');
        _elgg_services()->amdConfig->addPath('jquery.ui.autocomplete.html', $base_url.'mod/unl_theme/js/jquery.ui.autocomplete.html');
        
        //Tell elgg not to load its own version of require
        // WDN Template version 5.0 hack, use elgg version of require, jquery-ui, and jquery.imgareaselect
        //elgg_unregister_js('require');  // !!! Leave commented out ^
        //elgg_unregister_js('jquery-ui'); // !!! Leave commented out ^
        //elgg_unregister_js('jquery.imgareaselect'); // !!! Leave commented out ^
        
        //Load our own cropper that uses requirejs (make sure it loads last)
        elgg_register_js('elgg.avatar_cropper', $base_url.'mod/unl_theme/js/ui.avatar_cropper.js', 'head', 9000);
        
        //elgg_load_js("agency");
        elgg_load_js('respond');
        elgg_load_js("bootstrap");
        elgg_load_js("jscolor");
        elgg_load_js("unl_theme");
        elgg_load_js("bootstrap-select");
        elgg_load_js("jasny");
        elgg_load_js("parallax");
        elgg_load_js("scrollto");
        // elgg_require_js("fuelux");
        elgg_load_css("bootstrap");
        elgg_load_css("open");
        elgg_load_css("passion");
        elgg_load_css("font-awesome");
        elgg_load_css("bootstrap-select");
        elgg_load_css("unl_theme");
        elgg_load_css("jasny");
        // elgg_load_css("fuelux");
        elgg_load_css("agency");

        // Disable and Hide activity page
        elgg_unregister_page_handler('activity');
        elgg_unregister_menu_item('site', 'activity');
    }

    // non-members do not get visible links to RSS feeds
    if (!elgg_is_logged_in()) {
        elgg_unregister_plugin_hook_handler('output:before', 'layout', 'elgg_views_add_rss_link');
    }
    elgg_register_action("unl_theme/contact", elgg_get_plugins_path() . "unl_theme/actions/contact.php", "public");
}

/**
 * Rearrange menu items
 */
function unl_theme_pagesetup() {
    elgg_unextend_view('page/elements/header', 'search/header');
}

/**
 * Register items for the html head
 *
 * @param string $hook Hook name ('head')
 * @param string $type Hook type ('page')
 * @param array  $data Array of items for head
 * @return array
 */
function unl_theme_setup_head($hook, $type, $data) {
    $data['metas'][] = array(
        'name' => 'viewport',
        'content' => 'width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0',
    );
    $data['links'][] = array(
        'id' => 'favicon',
        'rel' => 'shortcut icon',
        'href' => 'https://unlcms.unl.edu/wdn/templates_4.1/includes/icons/favicon.ico',
    );
    $data['links'][] = array(
        'rel' => 'apple-touch-icon',
        'href' => elgg_normalize_url('mod/unl_theme/graphics/homescreen.png'),
    );

    return $data;
}



